Print a compact summary table for fuzzydid results.
Usage
# S3 method for class 'fuzzydid'
summary(object, ...)Value
The input object, returned invisibly with class
"fuzzydid", after printing the available estimator tables. This
method is called for its side effect of displaying the late,
eqtest, and lqte components in a compact tabular form.
Examples
make_example_cell <- function(g, t, ones, n_cell = 20L) {
data.frame(
g = rep.int(g, n_cell),
t = rep.int(t, n_cell),
d = c(rep.int(1L, ones), rep.int(0L, n_cell - ones))
)
}
df <- rbind(
make_example_cell(0L, 0L, 4L),
make_example_cell(0L, 1L, 8L),
make_example_cell(1L, 0L, 6L),
make_example_cell(1L, 1L, 16L)
)
df$id <- seq_len(nrow(df))
df$y <- 1 + 0.5 * df$g + 0.4 * df$t + 2 * df$d + sin(df$id / 7)
fit <- fuzzydid(
data = df[, c("y", "g", "t", "d")],
formula = y ~ d,
group = "g",
time = "t",
did = TRUE,
nose = TRUE
)
summary(fit)
#> LATE estimators
#> estimator estimate std.error conf.low conf.high
#> W_DID 3.225827 NA NA NA